@@ -24,7 +24,7 @@
  */
 
 #include "archive_platform.h"
-__FBSDID("$FreeBSD: src/lib/libarchive/archive_read_extract.c,v 1.60 2008/01/18 04:53:45 kientzle Exp $");
+__FBSDID("$FreeBSD: src/lib/libarchive/archive_read_extract.c,v 1.61 2008/05/26 17:00:22 kientzle Exp $");
 
 #ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
@@ -40,6 +40,7 @@ __FBSDID("$FreeBSD: src/lib/libarchive/archive_read_extract.c,v 1.60 2008/01/18
 #endif
 
 #include "archive.h"
+#include "archive_entry.h"
 #include "archive_private.h"
 #include "archive_read_private.h"
 #include "archive_write_disk_private.h"
@@ -82,34 +83,40 @@ get_extract(struct archive_read *a)
 int
 archive_read_extract(struct archive *_a, struct archive_entry *entry, int flags)
 {
-	struct archive_read *a = (struct archive_read *)_a;
 	struct extract *extract;
-	int r, r2;
 
-	extract = get_extract(a);
+	extract = get_extract((struct archive_read *)_a);
 	if (extract == NULL)
 		return (ARCHIVE_FATAL);
+	archive_write_disk_set_options(extract->ad, flags);
+	return (archive_read_extract2(_a, entry, extract->ad));
+}
+
+int
+archive_read_extract2(struct archive *_a, struct archive_entry *entry,
+    struct archive *ad)
+{
+	struct archive_read *a = (struct archive_read *)_a;
+	int r, r2;
 
 	/* Set up for this particular entry. */
-	extract = a->extract;
-	archive_write_disk_set_options(a->extract->ad, flags);
-	archive_write_disk_set_skip_file(a->extract->ad,
+	archive_write_disk_set_skip_file(ad,
 	    a->skip_file_dev, a->skip_file_ino);
-	r = archive_write_header(a->extract->ad, entry);
+	r = archive_write_header(ad, entry);
 	if (r < ARCHIVE_WARN)
 		r = ARCHIVE_WARN;
 	if (r != ARCHIVE_OK)
 		/* If _write_header failed, copy the error. */
- 		archive_copy_error(&a->archive, extract->ad);
-	else
+ 		archive_copy_error(&a->archive, ad);
+	else if (archive_entry_size(entry) > 0)
 		/* Otherwise, pour data into the entry. */
-		r = copy_data(_a, a->extract->ad);
-	r2 = archive_write_finish_entry(a->extract->ad);
+		r = copy_data(_a, ad);
+	r2 = archive_write_finish_entry(ad);
 	if (r2 < ARCHIVE_WARN)
 		r2 = ARCHIVE_WARN;
 	/* Use the first message. */
 	if (r2 != ARCHIVE_OK && r == ARCHIVE_OK)
- 		archive_copy_error(&a->archive, extract->ad);
+ 		archive_copy_error(&a->archive, ad);
 	/* Use the worst error return. */
 	if (r2 < r)
 		r = r2;
